# Alternatives

Importing Python objects from arbitrary locations specified as string is a common practice in many projects. There are also dedicated packages on PyPI, but none of them achieved significant popularity.

## Projects

Projects below use dynamic importing as helper utility:

* [django](https://github.com/django/django/blob/main/django/urls/utils.py)
* [gunicorn](https://github.com/benoitc/gunicorn/blob/master/gunicorn/util.py)
* [hypercorn](https://github.com/pgjones/hypercorn/blob/main/src/hypercorn/utils.py)
* [IPython](https://github.com/ipython/ipython/blob/main/IPython/utils/importstring.py)
* [pydantic](https://docs.pydantic.dev/latest/api/types/#pydantic.types.ImportString)
* [uvicorn](https://github.com/encode/uvicorn/blob/master/uvicorn/importer.py)

## PyPI Packages

_(to be added)_

